AnimatedLineChart class

Inheritance

Constructors

AnimatedLineChart(LineChart chart, {Key? key, TapText? tapText, TextStyle? textStyle, required Color gridColor, required Color toolTipColor, List<Legend>? legends = const [], bool? showMarkerLines = false, List<DateTime> verticalMarker = const [], Color? verticalMarkerColor, List<Icon>? verticalMarkerIcon = const [], Color? iconBackgroundColor, bool? fillMarkerLines = false, double? innerGridStrokeWidth = 0.0, List<MaxMin>? filledMarkerLinesValues = const [], bool? legendsRightLandscapeMode = false, bool? useLineColorsInTooltip = false, bool? showMinutesInTooltip = true})
const

Properties

chart → LineChart
LineChart is in charge of defining the lines which will be drawn in the graph.
final
filledMarkerLinesValues → List<MaxMin>?
Adds shaded area between markerlines: It is possible to have shaded areas between the defined markerlines
final
fillMarkerLines → bool?
Whether shaded areas between the defined markerlines should be shown or not. If true, the shaded area will have the same color as the markerline.
final
gridColor → Color
Color of grid
final
hashCode → int
The hash code for this object.
no setterinherited
iconBackgroundColor → Color?
The background color of the icons defined for 'verticalMarkerIcon'. This can be used for unfilled icons.
final
innerGridStrokeWidth → double?
Determines the stroke width of the inner grid of the chart.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
legends → List<Legend>?
List of legends.
final
legendsRightLandscapeMode → bool?
Whether legends should be drawn on the right-hand side of the graph when in landscape mode.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMarkerLines → bool?
Whether markerlines should be shown. Default to 'false'.
final
showMinutesInTooltip → bool?
Whether date shown in tooltip should include minutes or not.
final
tapText → TapText?
The text being displayed in the tooltip.
final
textStyle → TextStyle?
Style of tooltip text
final
toolTipColor → Color
Background color of tooltip
final
useLineColorsInTooltip → bool?
Whether color of tooltip text should be the same color as defined for LineChart color.
final
verticalMarker → List<DateTime>
A list of vertical lines can be defined.
final
verticalMarkerColor → Color?
The color of the vertical markerline.
final
verticalMarkerIcon → List<Icon>?
Icons can be defined, which will be drawn on the vertical markerline if 'verticalMarker' is defined.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AnimatedLineChartState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited