AreaLineChart class

Inheritance

Constructors

AreaLineChart(List<ChartLine> lines, Dates fromTo, List<Pair<Color, Color>>? _gradients, {FontWeight? tapTextFontWeight, String? yAxisName})
AreaLineChart.fromDateTimeMaps(List<Map<DateTime, double>> series, List<Color> colors, List<String> units, {List<Pair<Color, Color>>? gradients, FontWeight? tapTextFontWeight, String? yAxisName})
factory

Properties

axisOffSetWithPadding → double?
no setterinherited
fromTo → Dates
finalinherited
gradients → List<Pair<Color, Color>>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
heightStepSize → double?
no setterinherited
indexToUnit ↔ Map<int, String>
getter/setter pairinherited
lines → List<ChartLine>
finalinherited
maxX → double
no setterinherited
minX → double
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesMap → Map<int, List<HighlightPoint>>?
no setterinherited
showMonthsName → bool?
Whether only the name of the month should be shown on the x-axis.
finalinherited
tapTextFontWeight → FontWeight?
This is no longer being used.
final
width → double
no setterinherited
widthStepSize → double?
no setterinherited
xAxisOffsetPX → double
no setterinherited
xAxisOffsetPXright → double
no setterinherited
xAxisTexts → List<TextPainter>?
no setterinherited
xOffset → double?
no setterinherited
xScale → double?
no setterinherited
yAxisCount → int
no setterinherited
yAxisName ↔ String?
finalgetter/setter pairinherited-setteroverride-getter

Methods

getAreaPathCache(int index) → Path?
getClosetHighlightPoints(double horizontalDragPosition) → List<HighlightPoint>
inherited
getPathCache(int index) → Path?
inherited
height(String unit) → double
inherited
initialize(double widthPX, double heightPX, TextStyle? style) → void
inherited
maxY(String unit) → double?
inherited
minY(String unit) → double?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
yAxisTexts(int index) → List<TextPainter>?
inherited
yScale(String unit) → double?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited