ChartLine class

Constructors

ChartLine(List<ChartPoint> points, Color color, String unit, {bool isMarkerLine = false})

Properties

color → Color
final
hashCode → int
The hash code for this object.
no setterinherited
isMarkerLine ↔ bool
getter/setter pair
maxX → double
no setter
maxY → double
no setter
minX → double
no setter
minY → double
no setter
points → List<ChartPoint>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited