LineChart class

Implementers

Constructors

LineChart(List<ChartLine> lines, Dates fromTo, {bool? showMonthsName, FontWeight? tapTextFontWeight, String? yAxisName, String formatHoursMinutes = 'kk:mm', String formatDayMonth = 'dd/MM', String formatMonths = 'MMMM'})
LineChart.fromDateTimeMaps(List<Map<DateTime, double>> series, List<Color> colors, List<String> units, {FontWeight? tapTextFontWeight, bool? showMonthsName, String? yAxisName})
factory

Properties

axisOffSetWithPadding → double?
no setter
fromTo → Dates
final
hashCode → int
The hash code for this object.
no setterinherited
heightStepSize → double?
no setter
indexToUnit ↔ Map<int, String>
getter/setter pair
lines → List<ChartLine>
final
maxX → double
no setter
minX → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesMap → Map<int, List<HighlightPoint>>?
no setter
showMonthsName → bool?
Whether only the name of the month should be shown on the x-axis.
final
tapTextFontWeight → FontWeight?
This is no longer being used.
final
width → double
no setter
widthStepSize → double?
no setter
xAxisOffsetPX → double
no setter
xAxisOffsetPXright → double
no setter
xAxisTexts → List<TextPainter>?
no setter
xOffset → double?
no setter
xScale → double?
no setter
yAxisCount → int
no setter
yAxisName ↔ String?
getter/setter pair

Methods

getClosetHighlightPoints(double horizontalDragPosition) → List<HighlightPoint>
getPathCache(int index) → Path?
height(String unit) → double
initialize(double widthPX, double heightPX, TextStyle? style) → void
maxY(String unit) → double?
minY(String unit) → double?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
yAxisTexts(int index) → List<TextPainter>?
yScale(String unit) → double?

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

axisMargin → double
final
axisOffsetPX → double
final
stepCount → double
final